# AirAuth

Secure authentication for Air web framework sites.

## Getting started

- [Installation](installation.md) - how to install AirAuth
- [Usage](usage.md) - how to use AirAuth
- [API Reference](api.md) - auto-generated API documentation
